@@ -50,6 +50,8 @@
 !
   include 'cts_mprec.h'
   use scale
+  use combinatorics
+  use mbnvalues
   use loopfunctions
   use mp_loopfunctions
   use coefficients
@@ -84,7 +86,7 @@
    :: dbl_prec
   type(propagator), dimension(0:(number_propagators-1)) :: dn
   type(mp_propagator), dimension(0:number_propagators-1) :: mp_dn 
-  integer :: i,j,ib,k,dmr,npold= -1
+  integer :: i,j,ib,k,dmr,ierr
   logical, intent(out) :: stable
   logical :: stablen1,stablen2
   logical :: passeddp,passedmp
@@ -92,17 +94,56 @@
   logical :: firsttime=.true.
   include 'cts_dpr.h' 
    :: precstablen1,precstablen2
-  save firsttime,npold
+  save firsttime
   if (number_propagators.gt.maxden) then
    stop 'increase maxden in cts_combinatorics.f90'
   endif
   if ((imode.lt.0).or.(imode.gt.6)) then
    stop 'wrong input value of imode in ctsxcut'
   endif
-  if (number_propagators.ne.npold) then
-    call load_local_dimensions(number_propagators)
+!
+! Allocating local arrays
+!
+  ierr= -1
+  if (number_propagators.ge.1) then 
+   dmns_1= nbn1(number_propagators)
+   allocate  (bbn1(number_propagators,dmns_1), stat=ierr)
+   if (ierr.ne.0) STOP "Not enough memory to allocate bbn1"
+   bbn1= 0
   endif
-  npold= number_propagators
+  if (number_propagators.ge.2) then 
+   dmns_2= nbn2(number_propagators)
+   allocate  (bbn2(number_propagators,dmns_2), stat=ierr)
+   if (ierr.ne.0) STOP "Not enough memory to allocate bbn2"
+   bbn2= 0
+  endif
+  if (number_propagators.ge.3) then 
+   dmns_3= nbn3(number_propagators)
+   allocate  (bbn3(number_propagators,dmns_3), stat=ierr)
+   if (ierr.ne.0) STOP "Not enough memory to allocate bbn3"
+   bbn3= 0
+  endif
+  if (number_propagators.ge.4) then 
+   dmns_4= nbn4(number_propagators)
+   allocate  (bbn4(number_propagators,dmns_4), stat=ierr)
+   if (ierr.ne.0) STOP "Not enough memory to allocate bbn4"
+   bbn4= 0
+  endif
+!
+  do i= 1,number_propagators  
+   if (number_propagators.ge.1) then
+    do j= 1,dmns_1; bbn1(i,j)= bn1(number_propagators,i,j); enddo
+   endif
+   if (number_propagators.ge.2) then
+    do j= 1,dmns_2; bbn2(i,j)= bn2(number_propagators,i,j); enddo
+   endif
+   if (number_propagators.ge.3) then
+    do j= 1,dmns_3; bbn3(i,j)= bn3(number_propagators,i,j); enddo
+   endif
+   if (number_propagators.ge.4) then
+    do j= 1,dmns_4; bbn4(i,j)= bn4(number_propagators,i,j); enddo
+   endif
+  enddo
 !
 ! count the number of calls to ctsxcut
 !
@@ -375,6 +416,26 @@
   else
    stop 'wrong value of imode in ctsxcut'
   endif
+!
+! Deallocating local arrays
+!
+  ierr= -1
+  if (number_propagators.ge.1) then 
+   deallocate  (bbn1, stat=ierr)
+   if (ierr.ne.0) STOP "bbn1 NOT deallocated"
+  endif
+  if (number_propagators.ge.2) then 
+   deallocate  (bbn2, stat=ierr)
+   if (ierr.ne.0) STOP "bbn2 NOT deallocated"
+  endif
+  if (number_propagators.ge.3) then 
+   deallocate  (bbn3, stat=ierr)
+   if (ierr.ne.0) STOP "bbn3 NOT deallocated"
+  endif
+  if (number_propagators.ge.4) then 
+   deallocate  (bbn4, stat=ierr)
+   if (ierr.ne.0) STOP "bbn4 NOT deallocated"
+  endif
   contains
 !
   subroutine tag_as_unstable
@@ -416,17 +477,17 @@
      , intent(out) :: camp(0:2),campcc,campr1
     camp = 0.d0
     if (number_propagators.ge.4) then
-     do ib= 1,dmns_d
+     do ib= 1,dmns_4
       do k= 0,2; camp(k)= camp(k)+save_dcoeff(0,ib)*dloopfun(k,ib); enddo
      enddo
     endif
     if (number_propagators.ge.3) then
-     do ib= 1,dmns_c
+     do ib= 1,dmns_3
       do k= 0,2; camp(k)= camp(k)+save_ccoeff(0,ib)*cloopfun(k,ib); enddo
      enddo
     endif
     if (number_propagators.ge.2) then
-     do ib= 1,dmns_b
+     do ib= 1,dmns_2
       do k= 0,2
        camp(k)= camp(k)+ save_bcoeff(0,ib)               *bloopfun(k,ib)  &
                        +(save_bcoeff(3,ib)*vveck1(ib))   *b1loopfun(k,ib) &
@@ -435,7 +496,7 @@
      enddo
     endif
     if (number_propagators.ge.1) then
-     do ib= 1,dmns_a
+     do ib= 1,dmns_1
       do k= 0,2; camp(k)= camp(k)+save_acoeff(0,ib)*aloopfun(k,ib); enddo
      enddo
     endif 
@@ -453,21 +514,21 @@
      , intent(out) :: mp_camp(0:2),mp_campcc,mp_campr1
     do k= 0,2; mp_camp(k)= 0.d0; enddo
     if (number_propagators.ge.4) then
-     do ib= 1,dmns_d
+     do ib= 1,dmns_4
       do k= 0,2
         mp_camp(k)= mp_camp(k)+save_mp_dcoeff(0,ib)*mp_dloopfun(k,ib)
       enddo
      enddo
     endif
     if (number_propagators.ge.3) then
-     do ib= 1,dmns_c
+     do ib= 1,dmns_3
       do k= 0,2
        mp_camp(k)= mp_camp(k)+save_mp_ccoeff(0,ib)*mp_cloopfun(k,ib)
       enddo
      enddo
     endif
     if (number_propagators.ge.2) then
-     do ib= 1,dmns_b
+     do ib= 1,dmns_2
       do k= 0,2
        mp_camp(k)= mp_camp(k)+ save_mp_bcoeff(0,ib)    *mp_bloopfun(k,ib)  &
                +(save_mp_bcoeff(3,ib)*mp_vveck1(ib))   *mp_b1loopfun(k,ib) &
@@ -476,7 +537,7 @@
      enddo
     endif
     if (number_propagators.ge.1) then
-     do ib= 1,dmns_a
+     do ib= 1,dmns_1
       do k= 0,2
        mp_camp(k)= mp_camp(k)+save_mp_acoeff(0,ib)*mp_aloopfun(k,ib)
       enddo
